.site-footer {
	background: #efefef;
	font-size: 14px;	
	color: #888;
	padding: 70px 0;
	a {
		color: $primary;
		position: relative;
		display: inline-block;
	}
	.btn {
		&:before {
			display: none;
		}
	}
	.widget {
		margin-bottom: 40px;
		display: block;
		position: relative;
		z-index: 1;
		h3 {
			font-size: 16px;
			color: $black;
			margin-bottom: 30px;
			font-weight: 700;
		}

		.links {
			width: 150px;
			li {
				margin-bottom: 10px;
				a {
					color: #777;
				}
			}
		}
	}

	.social {
		li {
			display: inline-block;
			a {
				display: inline-block;
				width: 30px;
				height: 30px;
				position: relative;
				background: #777;
				border-radius: 50%;
				color: $white;
				&:before {
					display: none;
				}
				> span {
					position: absolute;
					top: 50%;
					left: 50%;
					transform: translate(-50%, -50%);
				}
				&:hover {
					background: lighten($primary, 10%);
					color: $white;
				}
			}
		}
	}

}
